use crate::{
	physics::{Pfloat, Polar},
	Doodad, Sprite, Spriteable,
};
use cgmath::{Deg, Point2};
use rand::{self, Rng};

pub struct StarfieldStar {
	// Star coordinates, in world space.
	// These are relative to the center of a starfield tile.
	pub pos: Point2<Pfloat>,
	pub parallax: Pfloat,
}

pub struct System {
	bodies: Vec<Doodad>,
	pub starfield: Vec<StarfieldStar>,
}

impl System {
	pub fn new() -> Self {
		let mut rng = rand::thread_rng();
		let mut s = System {
			bodies: Vec::new(),
			starfield: (0..500)
				.map(|_| StarfieldStar {
					pos: Point2 {
						x: rng.gen_range(-500.0..500.0),
						y: rng.gen_range(-500.0..500.0),
					},
					parallax: rng.gen_range(10.0..11.0),
				})
				.collect(),
		};

		s.bodies.push(Doodad {
			pos: (0.0, 0.0).into(),
			sprite: "a0".to_owned(),
			parallax: 3.0,
			height: 80.0,
		});

		s.bodies.push(Doodad {
			pos: Polar {
				center: (0.0, 0.0).into(),
				radius: 100.0,
				angle: Deg { 0: 31.0 },
			}
			.to_cartesian(),
			sprite: "earth".to_owned(),
			parallax: 1.0,
			height: 120.0,
		});

		s.bodies.push(Doodad {
			pos: Polar {
				center: (0.0, 0.0).into(),
				radius: 200.0,
				angle: Deg { 0: 270.0 },
			}
			.to_cartesian(),
			sprite: "small".to_owned(),
			parallax: -1.0,
			height: 50.0,
		});

		return s;
	}

	pub fn sprites(&self) -> Vec<Sprite> {
		return self.bodies.iter().map(|x| x.sprite()).collect();
	}
}
